@@ -10,7 +10,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "lib.h"
@@ -1019,14 +1019,13 @@ static struct volume_group *_read_vg(struct format_instance *fid,
 static void _read_desc(struct dm_pool *mem,
 		       const struct dm_config_tree *cft, time_t *when, char **desc)
 {
-	const char *d;
+	const char *str;
 	unsigned int u = 0u;
-	int old_suppress;
 
-	old_suppress = log_suppress(1);
-	d = dm_config_find_str_allow_empty(cft->root, "description", "");
-	log_suppress(old_suppress);
-	*desc = dm_pool_strdup(mem, d);
+	if (!dm_config_get_str(cft->root, "description", &str))
+		str = "";
+
+	*desc = dm_pool_strdup(mem, str);
 
 	(void) dm_config_get_uint32(cft->root, "creation_time", &u);
 	*when = u;
@@ -1042,12 +1041,13 @@ static int _read_vgname(const struct format_type *fmt, const struct dm_config_tr
 {
 	const struct dm_config_node *vgn;
 	struct dm_pool *mem = fmt->cmd->mem;
-	int old_suppress;
+	const char *str;
 
-	old_suppress = log_suppress(2);
-	vgsummary->creation_host =
-	    dm_pool_strdup(mem, dm_config_find_str_allow_empty(cft->root, "creation_host", ""));
-	log_suppress(old_suppress);
+	if (!dm_config_get_str(cft->root, "creation_host", &str))
+		str = "";
+
+	if (!(vgsummary->creation_host = dm_pool_strdup(mem, str)))
+		return_0;
 
 	/* skip any top-level values */
 	for (vgn = cft->root; (vgn && vgn->v); vgn = vgn->sib) ;
@@ -1073,7 +1073,13 @@ static int _read_vgname(const struct format_type *fmt, const struct dm_config_tr
 		return 0;
 	}
 
-	dm_config_get_str(vgn, "lock_type", &vgsummary->lock_type);
+	if (dm_config_get_str(vgn, "system_id", &str) &&
+	    (!(vgsummary->system_id = dm_pool_strdup(mem, str))))
+		return_0;
+
+	if (dm_config_get_str(vgn, "lock_type", &str) &&
+	    (!(vgsummary->lock_type = dm_pool_strdup(mem, str))))
+		return_0;
 
 	return 1;
 }
