@@ -10,7 +10,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "lib.h"
@@ -49,10 +49,7 @@ static size_t _lvm_errmsg_len = 0;
 
 void init_log_fn(lvm2_log_fn_t log_fn)
 {
-	if (log_fn)
-		_lvm2_log_fn = log_fn;
-	else
-		_lvm2_log_fn = NULL;
+	_lvm2_log_fn = log_fn;
 }
 
 /*
@@ -267,9 +264,8 @@ void print_log(int level, const char *file, int line, int dm_errno_or_class,
 	       const char *format, ...)
 {
 	va_list ap;
-	char buf[1024], locn[4096];
+	char buf[1024], message[4096];
 	int bufused, n;
-	const char *message;
 	const char *trformat;		/* Translated format string */
 	char *newbuf;
 	int use_stderr = level & _LOG_STDERR;
@@ -303,9 +299,6 @@ void print_log(int level, const char *file, int line, int dm_errno_or_class,
 		level = _LOG_FATAL;
 	}
 
-	if (_log_suppress == 2)
-		return;
-
 	if (level <= _LOG_ERR)
 		init_error_message_produced(1);
 
@@ -318,17 +311,16 @@ void print_log(int level, const char *file, int line, int dm_errno_or_class,
 	    (_store_errmsg && (level <= _LOG_ERR)) ||
 	    log_once) {
 		va_start(ap, format);
-		n = vsnprintf(locn, sizeof(locn) - 1, trformat, ap);
+		n = vsnprintf(message, sizeof(message), trformat, ap);
 		va_end(ap);
 
+		/* When newer glibc returns >= sizeof(locn), we will just log what
+                 * has fit into buffer, it's '\0' terminated string */
 		if (n < 0) {
 			fprintf(stderr, _("vsnprintf failed: skipping external "
 					"logging function"));
 			goto log_it;
 		}
-
-		locn[sizeof(locn) - 1] = '\0';
-		message = locn;
 	}
 
 /* FIXME Avoid pointless use of message buffer when it'll never be read! */
@@ -444,20 +436,24 @@ void print_log(int level, const char *file, int line, int dm_errno_or_class,
 		_already_logging = 1;
 		memset(&buf, ' ', sizeof(buf));
 		bufused = 0;
-		if ((n = dm_snprintf(buf, sizeof(buf) - 1,
+		if ((n = dm_snprintf(buf, sizeof(buf),
 				      "%s:%d %s%s", file, line, log_command_name(),
 				      _msg_prefix)) == -1)
 			goto done;
 
-		bufused += n;
+		bufused += n;		/* n does not include '\0' */
 
 		va_start(ap, format);
-		n = vsnprintf(buf + bufused - 1, sizeof(buf) - bufused - 1,
+		n = vsnprintf(buf + bufused, sizeof(buf) - bufused,
 			      trformat, ap);
 		va_end(ap);
-		bufused += n;
 
-		buf[bufused - 1] = '\n';
+		if (n < 0)
+			goto done;
+
+		bufused += n;
+		if (n >= sizeof(buf))
+			bufused = sizeof(buf) - 1;
 	      done:
 		buf[bufused] = '\n';
 		buf[sizeof(buf) - 1] = '\n';
