@@ -7,7 +7,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+SKIP_WITH_LVMPOLLD=1
 
 . lib/inittest
 
@@ -25,7 +27,7 @@ dmsetup status
 echo n | lvconvert --repair $vg/4way 2>&1 | tee 4way.out
 aux enable_dev --silent "$dev2" "$dev4"
 
-lvs -a -o +devices | tee out
+lvs -a -o +devices $vg | tee out
 not grep unknown out
 vgreduce --removemissing $vg
 check mirror $vg 4way
