@@ -7,15 +7,16 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 # 'Exercise some lvcreate diagnostics'
 
+SKIP_WITH_LVMPOLLD=1
+
 . lib/inittest
 
 # FIXME  update test to make something useful on <16T
 aux can_use_16T || skip
-
 aux have_raid 1 3 0 || skip
 
 aux prepare_vg 5
