@@ -7,13 +7,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-. lib/inittest
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 # lvmetad does not handle pool labels so skip test.
-test ! -e LOCAL_LVMETAD || skip
-test -e LOCAL_LVMPOLLD && skip
+SKIP_WITH_LVMETAD=1
+SKIP_WITH_LVMPOLLD=1
+
+. lib/inittest
 
 env printf "" || skip # skip if printf is not available
 
