@@ -7,10 +7,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 # 'Test pvchange option values'
 
+SKIP_WITH_LVMPOLLD=1
+
 . lib/inittest
 
 check_changed_uuid_() {
