@@ -7,12 +7,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 test_description="ensure pvmove works with thin segment types"
+SKIP_WITH_CLVMD=1
 
 . lib/inittest
-test -e LOCAL_CLVMD && skip
+
 which md5sum || skip
 
 aux have_thin 1 8 0 || skip
