@@ -7,7 +7,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 SKIP_WITH_LVMETAD=1
 SKIP_WITH_CLVMD=1
@@ -24,16 +24,10 @@ aux lvmconf "report/mark_hidden_devices = 0"
 lvs --noheadings -a -o name $vg > out
 grep "^${lv1}_mimage_0" out
 not grep "^\[${lv1}_mimage_0\]" out
-lvs --noheadings -a -o devices $vg/$lv1 > out
-grep "^${lv1}_mimage_0" out
-not grep "^\[${lv1}_mimage_0\]" out
 
 aux lvmconf "report/mark_hidden_devices = 1"
 lvs --noheadings -a -o name $vg > out
 grep "^\[${lv1}_mimage_0\]" out
 not grep "^${lv1}_mimage_0" out
-lvs --noheadings -a -o devices $vg/$lv1 > out
-grep "^\[${lv1}_mimage_0\]" out
-not grep "^${lv1}_mimage_0" out
 
 vgremove -ff $vg
